// set the dimensions and margins of the graph
const width = 800;
const height = 500;

// append the svg object to the body of the page
// two different svgs on the page...
const svg = d3
  .select('#my_dataviz') // # for class
  .append('svg')
  .attr('width', width / 2)
  .attr('height', height);

const svg2 = d3
  .select('#my_dataviz')
  .append('svg')
  .attr('width', width / 2)
  .attr('height', height);

// css styling of divs default is to stuff things next to each other... go left to right ( until run out of space), then top to bottom
// so if we want to change the layout default we would need to change the div)

// render aka, draw
function render(mapData, countryData) {
  // drawing a map //.1 need a projection// 2. need a path
  var projection = d3
    .geoEqualEarth()
    .fitSize([width / 2, height], mapData);
  // path takes a d attribute, which is the path
  //longitude lattitude to pixel coordinate units

  var path = d3.geoPath(projection);

  const colorAttr = 'Birth Rate';
  const xDataRange = d3.extent(
    d3.map(countryData.values(), (v) => +v[colorAttr]),
  );

  // console.log(countryData.values());
  // console.log(xDataRange);

  var colorScale = d3
    .scaleLinear()
    // .domain([0, 50])
    .domain(xDataRange)
    .range(['blue', 'red']);

  // append a group
  // d is the metric for paths..
  svg
    .append('g')
    .selectAll('path')
    .data(mapData.features)
    .join('path')
    .attr('d', path)
    .attr('fill', (d) => {
      if (countryData.has(d.properties.name)) {
        return colorScale(
          countryData.get(d.properties.name)[colorAttr],
        );
      } else {
        return 'grey';
      }
    });
}

//Read the data
// we need three data sets...
//1. Geo jason data (googled world country geojason )
//2. The core data, this is the world data
//3. need contenant data so I can color code by contentant (googled )

const mapUrl =
  'https://raw.githubusercontent.com/holtzy/D3-graph-gallery/master/DATA/world.geojson';
const countryStatsUrl =
  'https://raw.githubusercontent.com/bepnye/CP341/main/world-data-2023.csv';
const continentUrl =
  'https://raw.githubusercontent.com/samayo/country-json/master/src/country-by-continent.json';

function normalizeCountryName(s) {
  return s.replaceAll(' ', '_').toLowerCase();
}

// loading all the data... and parse the data...
// async... once all these are resolved then run the .then() block
Promise.all([
  d3.json(mapUrl),
  d3.csv(countryStatsUrl),
  d3.json(continentUrl),
]).then(([mapData, csvData, continentData]) => {
  // auto declaring, bind these vars to the results of d3.json(mapUrl)...
  // so mapData =  d3.json(mapUrl), csvData = d3.csv(countryStatsUrl)...

  // console.log(mapData);
  // console.log(csvData);
  // console.log(continentData);

  // handling the data
  var countryData = new Map(); // hashmap or dictionary
  csvData.forEach((row) => {
    row.Population = row.Population.replaceAll(',', '');
    row['Co2-Emissions'] = row['Co2-Emissions'].replaceAll(
      ',',
      '',
    );

    countryData.set(row.Country, row);
  });
  // console.log(countryData);
  // call render
  render(mapData, countryData);
});
